@@ -33,10 +33,20 @@ class Droplet(BaseAPI):
         self.backups = None
         self.ipv6 = None
         self.private_networking = None
+        self.user_data = None
 
         # This will load also the values passed
         super(Droplet, self).__init__(*args, **kwargs)
 
+    @classmethod
+    def get_object(cls, api_token, droplet_id):
+        """
+            Class method that will return a Droplet object by ID.
+        """
+        droplet = cls(token=api_token, id=droplet_id)
+        droplet.load()
+        return droplet
+
     def __check_actions_in_data(self, data):
         # reloading actions if actions is provided.
         if data.has_key(u"actions"):
@@ -241,7 +251,7 @@ class Droplet(BaseAPI):
             params={'type' : 'change_kernel', 'kernel': kernel.id}
         )
 
-    def create(self, ssh_keys=None, backups=False, ipv6=False, private_networking=False):
+    def create(self, ssh_keys=None, backups=False, ipv6=False, private_networking=False, user_data=None):
         """
             Create the droplet with object properties.
         """
@@ -253,6 +263,9 @@ class Droplet(BaseAPI):
                 "ssh_keys[]": self.ssh_keys
             }
 
+        if user_data:
+            data["user_data"] = user_data
+
         if ssh_keys:
             if type(ssh_keys) in [int, long, str]:
                 data['ssh_keys[]']= str(ssh_keys)
@@ -270,6 +283,9 @@ class Droplet(BaseAPI):
         if self.private_networking:
             data['private_networking'] = True
 
+        if self.user_data:
+            data["user_data"] = self.user_data
+
         data = self.get_data(
             "droplets",
             type="POST",
@@ -310,6 +326,15 @@ class Droplet(BaseAPI):
             actions.append(action)
         return actions
 
+    def get_action(self, action_id):
+        """
+            Returns a specific Action by its ID.
+        """
+        return Action.get_object(
+            api_token=self.token,
+            action_id=action_id
+        )
+
     def get_snapshots(self):
         """
             This method will return the snapshots/images connected to that
@@ -343,4 +368,4 @@ class Droplet(BaseAPI):
         return kernels
 
     def __str__(self):
-        return "%s %s" % (self.id, self.name)
\ No newline at end of file
+        return "%s %s" % (self.id, self.name)
